// created by jay 0.7 (c) 1998 Axel.Schreiner@informatik.uni-osnabrueck.de

#line 2 "Parser.jay"
using System.Text;
using System.IO;
using System.Collections;
using System;

namespace Mono.Debugger.Frontends.CommandLine
{
	internal class Parser
	{
		ScriptingContext current_context;
		MyTextReader reader;
		bool do_quit = false;

		protected bool yacc_verbose_flag = false;

		public bool yacc_verbose {
			set {
				yacc_verbose_flag = value;
			}

			get {
				return yacc_verbose_flag;
			}
		}

		public bool Quit {
			get {
				return do_quit;
			}
		}

		Tokenizer lexer;

		public Tokenizer Lexer {
			get {
				return lexer;
			}
		}		   

#line default

  /** simplified error message.
      @see <a href="#yyerror(java.lang.String, java.lang.String[])">yyerror</a>
    */
  public void yyerror (string message) {
    yyerror(message, null);
  }

  /** (syntax) error message.
      Can be overwritten to control message format.
      @param message text to be displayed.
      @param expected vector of acceptable tokens, if available.
    */
  public void yyerror (string message, string[] expected) {
    if ((expected != null) && (expected.Length  > 0)) {
      System.Console.Write (message+", expecting");
      for (int n = 0; n < expected.Length; ++ n)
        System.Console.Write (" "+expected[n]);
        System.Console.WriteLine ();
    } else
      System.Console.WriteLine (message);
  }

  /** debugging support, requires the package jay.yydebug.
      Set to null to suppress debugging messages.
    */
  protected yydebug.yyDebug debug;

  protected static  int yyFinal = 2;
  public static  string [] yyRule = {
    "$accept : command_loop",
    "command_loop :",
    "command_loop : command_loop command EOL",
    "command_loop : command_loop EOL",
    "command_loop : command_loop EOF",
    "command_loop : QUIT EOL",
    "command : generated_command",
    "command : other_command",
    "command : assert_command",
    "generated_command : CONTINUE process_expression",
    "generated_command : STEP process_expression",
    "generated_command : NEXT process_expression",
    "generated_command : STEPI process_expression",
    "generated_command : NATIVE STEPI process_expression",
    "generated_command : NEXTI process_expression",
    "generated_command : FINISH process_expression",
    "generated_command : BACKTRACE process_expression opt_count",
    "generated_command : UP process_expression",
    "generated_command : DOWN process_expression",
    "generated_command : KILL",
    "generated_command : RUN",
    "generated_command : SHOW PROCESSES",
    "generated_command : SHOW REGISTERS frame_expression",
    "generated_command : SHOW PARAMETERS frame_expression",
    "generated_command : SHOW LOCALS frame_expression",
    "generated_command : SHOW MODULES",
    "generated_command : SHOW SOURCES module_list_expression",
    "generated_command : SHOW METHODS source_list_expression",
    "generated_command : SHOW BREAKPOINTS",
    "generated_command : SHOW THREADGROUPS",
    "generated_command : SHOW TYPE variable_expression",
    "generated_command : BREAK thread_group_expression source_expression",
    "generated_command : BREAKPOINT ENABLE process_expression breakpoint_number_expression",
    "generated_command : BREAKPOINT DISABLE process_expression breakpoint_number_expression",
    "generated_command : BREAKPOINT DELETE process_expression breakpoint_number_expression",
    "generated_command : FRAME frame_expression",
    "generated_command : DISASSEMBLE frame_expression",
    "generated_command : DISASSEMBLE METHOD frame_expression",
    "generated_command : PROCESS process_expression",
    "generated_command : BACKGROUND process_expression",
    "generated_command : STOP process_expression",
    "generated_command : MODULE module_list_expression module_operations",
    "generated_command : THREADGROUP CREATE STRING",
    "generated_command : THREADGROUP ADD STRING process_list_expression",
    "generated_command : THREADGROUP REMOVE STRING process_list_expression",
    "generated_command : LIST source_expression",
    "generated_command : LIST CONTINUE",
    "other_command : SAVE STRING",
    "other_command : SET BANG IDENTIFIER ASSIGN variable_expression",
    "other_command : SET variable_expression ASSIGN expression",
    "other_command : PRINT expression",
    "other_command : PRINT type_expression",
    "other_command : EXAMINE examine_format variable_expression",
    "other_command : EXAMINE examine_format frame_prefix NUMBER",
    "other_command : CALL variable_expression OPEN_PARENS argument_list CLOSE_PARENS",
    "other_command : START program_arguments_expression",
    "other_command : REPEAT command",
    "kind : UNKNOWN",
    "kind : FUNDAMENTAL",
    "kind : ARRAY",
    "kind : STRUCT",
    "kind : CLASS",
    "kind : POINTER",
    "assert_command : ASSERT KIND kind variable_expression",
    "assert_command : ASSERT ACCESSIBLE variable_expression",
    "assert_command : ASSERT NOT ACCESSIBLE variable_expression",
    "assert_command : ASSERT TYPE STRING variable_expression",
    "assert_command : ASSERT CONTENTS STRING variable_expression",
    "assert_command : ASSERT LINE INTEGER",
    "expression : LENGTH OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : LOWER OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : UPPER OPEN_PARENS variable_expression CLOSE_PARENS",
    "expression : NUMBER",
    "expression : INTEGER",
    "expression : STRING",
    "expression : expression binary_operator expression",
    "expression : OPEN_PARENS expression CLOSE_PARENS",
    "expression : variable_expression",
    "type_expression : TYPEOF OPEN_PARENS variable_expression CLOSE_PARENS",
    "type_expression : TYPEOF OPEN_PARENS frame_prefix type_name CLOSE_PARENS",
    "type_name : IDENTIFIER",
    "type_name : type_name DOT IDENTIFIER",
    "variable_expression : STAR variable_expression",
    "variable_expression : BANG IDENTIFIER",
    "variable_expression : BANG BANG",
    "variable_expression : frame_prefix DOLLAR IDENTIFIER",
    "variable_expression : frame_prefix PERCENT NUMBER",
    "variable_expression : frame_prefix PERCENT IDENTIFIER opt_regoffset",
    "variable_expression : frame_prefix type_expression DOT IDENTIFIER",
    "variable_expression : frame_prefix type_name COLON IDENTIFIER",
    "variable_expression : variable_expression DOT IDENTIFIER",
    "variable_expression : variable_expression MINUS OP_GT IDENTIFIER",
    "variable_expression : variable_expression OPEN_BRACKET expression CLOSE_BRACKET",
    "variable_expression : variable_expression OPEN_PARENS argument_list CLOSE_PARENS",
    "variable_expression : NEW frame_prefix type_name OPEN_PARENS argument_list CLOSE_PARENS",
    "variable_expression : PARENT OPEN_PARENS variable_expression CLOSE_PARENS",
    "variable_expression : OPEN_PARENS variable_expression CLOSE_PARENS",
    "program_arguments_expression : program_arglist",
    "program_arglist : STRING",
    "program_arglist : program_arglist STRING",
    "argument_list :",
    "argument_list : argument_list_0",
    "argument_list_0 : expression",
    "argument_list_0 : argument_list_0 COMMA expression",
    "examine_format :",
    "examine_format : DIV integer_or_number",
    "opt_count :",
    "opt_count : INTEGER",
    "opt_regoffset :",
    "opt_regoffset : PLUS integer_or_number",
    "opt_regoffset : MINUS integer_or_number",
    "integer_or_number : INTEGER",
    "integer_or_number : NUMBER",
    "breakpoint_number_expression : INTEGER",
    "thread_group_expression :",
    "thread_group_expression : OP_LT IDENTIFIER OP_GT",
    "thread_group_expression : OP_LT GLOBAL OP_GT",
    "process_expression :",
    "process_expression : AT INTEGER",
    "frame_expression : process_expression",
    "frame_expression : process_expression HASH INTEGER",
    "process_prefix :",
    "process_prefix : AT INTEGER COLON",
    "frame_prefix : process_prefix",
    "frame_prefix : process_prefix HASH INTEGER COLON",
    "opt_line :",
    "opt_line : COLON INTEGER",
    "source_expression : variable_expression opt_line",
    "source_expression : BANG INTEGER",
    "source_expression : STRING",
    "source_expression : STRING COLON INTEGER",
    "module_list_expression : number_list",
    "source_list_expression : number_list",
    "process_list_expression : number_list",
    "number_list : INTEGER",
    "number_list : number_list COMMA INTEGER",
    "module_operation : IGNORE",
    "module_operation : UNIGNORE",
    "module_operation : BANG IGNORE",
    "module_operation : STEP",
    "module_operation : BANG STEP",
    "module_operations : module_operation_list",
    "module_operation_list : module_operation",
    "module_operation_list : module_operation_list module_operation",
    "binary_operator : STAR",
    "binary_operator : PLUS",
    "binary_operator : MINUS",
    "binary_operator : DIV",
  };
  protected static  string [] yyNames = {    
    "end-of-file",null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,null,null,null,null,null,null,null,
    null,null,null,null,null,null,null,"QUIT","EOL","EOF","NONE","ERROR",
    "IDENTIFIER","INTEGER","NUMBER","STRING","HASH","AT","PERCENT",
    "DOLLAR","DOT","BANG","COMMA","ASSIGN","STAR","PLUS","MINUS","DIV",
    "OPEN_PARENS","CLOSE_PARENS","OPEN_BRACKET","CLOSE_BRACKET","OP_LT",
    "OP_GT","COLON","PROCESSES","REGISTERS","PARAMETERS","LOCALS","TYPE",
    "METHOD","PARENT","LENGTH","LOWER","UPPER","KIND","ACCESSIBLE",
    "CONTENTS","LINE","NOT","UNKNOWN","FUNDAMENTAL","ARRAY","STRUCT",
    "CLASS","POINTER","MODULES","SOURCES","METHODS","BREAKPOINTS",
    "THREADGROUPS","GLOBAL","FRAME","START","SHOW","PROCESS","CONTINUE",
    "BACKTRACE","UP","DOWN","STEP","NEXT","STEPI","NEXTI","FINISH",
    "BREAK","PRINT","DISASSEMBLE","SET","ASSERT","BREAKPOINT","SAVE",
    "KILL","THREADGROUP","SEARCH","LIST","RUN","EXAMINE","CALL","NEW",
    "REPEAT","NATIVE","SELECT","BACKGROUND","STOP","MODULE","IGNORE",
    "UNIGNORE","ALL","ENABLE","DISABLE","DELETE","CREATE","ADD","REMOVE",
    "TYPEOF","HELP",
  };

  /** index-checked interface to yyNames[].
      @param token single character or %token value.
      @return token name or [illegal] or [unknown].
    */
  public static string yyname (int token) {
    if ((token < 0) || (token > yyNames.Length)) return "[illegal]";
    string name;
    if ((name = yyNames[token]) != null) return name;
    return "[unknown]";
  }

  /** computes list of expected tokens on error by tracing the tables.
      @param state for which to compute the list.
      @return list of token names.
    */
  protected string[] yyExpecting (int state) {
    int token, n, len = 0;
    bool[] ok = new bool[yyNames.Length];

    if ((n = yySindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyNames.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyNames[token] != null) {
          ++ len;
          ok[token] = true;
        }
    if ((n = yyRindex[state]) != 0)
      for (token = n < 0 ? -n : 0;
           (token < yyNames.Length) && (n+token < yyTable.Length); ++ token)
        if (yyCheck[n+token] == token && !ok[token] && yyNames[token] != null) {
          ++ len;
          ok[token] = true;
        }

    string [] result = new string[len];
    for (n = token = 0; n < len;  ++ token)
      if (ok[token]) result[n++] = yyNames[token];
    return result;
  }

  /** the generated parser, with debugging messages.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @param yydebug debug message writer implementing yyDebug, or null.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  public Object yyparse (yyParser.yyInput yyLex, Object yyd)
				 {
    this.debug = (yydebug.yyDebug)yyd;
    return yyparse(yyLex);
  }

  /** initial size and increment of the state/value stack [default 256].
      This is not final so that it can be overwritten outside of invocations
      of yyparse().
    */
  protected int yyMax;

  /** executed at the beginning of a reduce action.
      Used as $$ = yyDefault($1), prior to the user-specified action, if any.
      Can be overwritten to provide deep copy, etc.
      @param first value for $1, or null.
      @return first.
    */
  protected Object yyDefault (Object first) {
    return first;
  }

  /** the generated parser.
      Maintains a state and a value stack, currently with fixed maximum size.
      @param yyLex scanner.
      @return result of the last reduction, if any.
      @throws yyException on irrecoverable parse error.
    */
  public Object yyparse (yyParser.yyInput yyLex)
				{
    if (yyMax <= 0) yyMax = 256;			// initial size
    int yyState = 0;                                   // state stack ptr
    int [] yyStates = new int[yyMax];	                // state stack 
    Object yyVal = null;                               // value stack ptr
    Object [] yyVals = new Object[yyMax];	        // value stack
    int yyToken = -1;					// current input
    int yyErrorFlag = 0;				// #tks to shift

    int yyTop = 0;
    goto skip;
    yyLoop:
    yyTop++;
    skip:
    for (;; ++ yyTop) {
      if (yyTop >= yyStates.Length) {			// dynamically increase
        int[] i = new int[yyStates.Length+yyMax];
        yyStates.CopyTo (i, 0);
        yyStates = i;
        Object[] o = new Object[yyVals.Length+yyMax];
        yyVals.CopyTo (o, 0);
        yyVals = o;
      }
      yyStates[yyTop] = yyState;
      yyVals[yyTop] = yyVal;
      if (debug != null) debug.push(yyState, yyVal);

      yyDiscarded: for (;;) {	// discarding a token does not change stack
        int yyN;
        if ((yyN = yyDefRed[yyState]) == 0) {	// else [default] reduce (yyN)
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
            if (debug != null)
              debug.lex(yyState, yyToken, yyname(yyToken), yyLex.value());
          }
          if ((yyN = yySindex[yyState]) != 0 && ((yyN += yyToken) >= 0)
              && (yyN < yyTable.Length) && (yyCheck[yyN] == yyToken)) {
            if (debug != null)
              debug.shift(yyState, yyTable[yyN], yyErrorFlag-1);
            yyState = yyTable[yyN];		// shift to yyN
            yyVal = yyLex.value();
            yyToken = -1;
            if (yyErrorFlag > 0) -- yyErrorFlag;
            goto yyLoop;
          }
          if ((yyN = yyRindex[yyState]) != 0 && (yyN += yyToken) >= 0
              && yyN < yyTable.Length && yyCheck[yyN] == yyToken)
            yyN = yyTable[yyN];			// reduce (yyN)
          else
            switch (yyErrorFlag) {
  
            case 0:
              yyerror("syntax error", yyExpecting(yyState));
              if (debug != null) debug.error("syntax error");
              goto case 1;
            case 1: case 2:
              yyErrorFlag = 3;
              do {
                if ((yyN = yySindex[yyStates[yyTop]]) != 0
                    && (yyN += Token.yyErrorCode) >= 0 && yyN < yyTable.Length
                    && yyCheck[yyN] == Token.yyErrorCode) {
                  if (debug != null)
                    debug.shift(yyStates[yyTop], yyTable[yyN], 3);
                  yyState = yyTable[yyN];
                  yyVal = yyLex.value();
                  goto yyLoop;
                }
                if (debug != null) debug.pop(yyStates[yyTop]);
              } while (-- yyTop >= 0);
              if (debug != null) debug.reject();
              throw new yyParser.yyException("irrecoverable syntax error");
  
            case 3:
              if (yyToken == 0) {
                if (debug != null) debug.reject();
                throw new yyParser.yyException("irrecoverable syntax error at end-of-file");
              }
              if (debug != null)
                debug.discard(yyState, yyToken, yyname(yyToken),
  							yyLex.value());
              yyToken = -1;
              goto yyDiscarded;		// leave stack alone
            }
        }
        int yyV = yyTop + 1-yyLen[yyN];
        if (debug != null)
          debug.reduce(yyState, yyStates[yyV-1], yyN, yyRule[yyN], yyLen[yyN]);
        yyVal = yyDefault(yyV > yyTop ? null : yyVals[yyV]);
        switch (yyN) {
case 2:
#line 158 "Parser.jay"
  {
		((Command) yyVals[-1+yyTop]).Execute (current_context);
	  }
  break;
case 5:
#line 164 "Parser.jay"
  {
		do_quit = true;
		reader.Close ();
	  }
  break;
case 9:
#line 174 "Parser.jay"
  {
		yyVal = new ContinueCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 10:
#line 178 "Parser.jay"
  {
		yyVal = new StepCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 11:
#line 182 "Parser.jay"
  {
		yyVal = new NextCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 12:
#line 186 "Parser.jay"
  {
		yyVal = new StepInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 13:
#line 190 "Parser.jay"
  {
		yyVal = new StepNativeInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 14:
#line 194 "Parser.jay"
  {
		yyVal = new NextInstructionCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 15:
#line 198 "Parser.jay"
  {
		yyVal = new FinishCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 16:
#line 202 "Parser.jay"
  {
		yyVal = new BacktraceCommand ((ProcessExpression) yyVals[-1+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 17:
#line 206 "Parser.jay"
  {
		yyVal = new UpCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 18:
#line 210 "Parser.jay"
  {
		yyVal = new DownCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 19:
#line 214 "Parser.jay"
  {
		yyVal = new KillCommand ();
	  }
  break;
case 20:
#line 218 "Parser.jay"
  {
		yyVal = new RunCommand ();
	  }
  break;
case 21:
#line 222 "Parser.jay"
  {
		yyVal = new ShowProcessesCommand ();
	  }
  break;
case 22:
#line 226 "Parser.jay"
  {
		yyVal = new ShowRegistersCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 23:
#line 230 "Parser.jay"
  {
		yyVal = new ShowParametersCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 24:
#line 234 "Parser.jay"
  {
		yyVal = new ShowLocalsCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 25:
#line 238 "Parser.jay"
  {
		yyVal = new ShowModulesCommand ();
	  }
  break;
case 26:
#line 242 "Parser.jay"
  {
		yyVal = new ShowSourcesCommand ((ModuleListExpression) yyVals[0+yyTop]);
	  }
  break;
case 27:
#line 246 "Parser.jay"
  {
		yyVal = new ShowMethodsCommand ((SourceListExpression) yyVals[0+yyTop]);
	  }
  break;
case 28:
#line 250 "Parser.jay"
  {
		yyVal = new ShowBreakpointsCommand ();
	  }
  break;
case 29:
#line 254 "Parser.jay"
  {
		yyVal = new ShowThreadGroupsCommand ();
	  }
  break;
case 30:
#line 258 "Parser.jay"
  {
		yyVal = new ShowVariableTypeCommand ((VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 31:
#line 262 "Parser.jay"
  {
		yyVal = new BreakCommand ((ThreadGroupExpression) yyVals[-1+yyTop], (SourceExpression) yyVals[0+yyTop]);
	  }
  break;
case 32:
#line 266 "Parser.jay"
  {
		yyVal = new BreakpointEnableCommand ((ProcessExpression) yyVals[-1+yyTop],
						  (BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 33:
#line 271 "Parser.jay"
  {
		yyVal = new BreakpointDisableCommand ((ProcessExpression) yyVals[-1+yyTop],
						   (BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 34:
#line 276 "Parser.jay"
  {
		yyVal = new BreakpointDeleteCommand ((ProcessExpression) yyVals[-1+yyTop],
						  (BreakpointNumberExpression) yyVals[0+yyTop]);
	  }
  break;
case 35:
#line 281 "Parser.jay"
  {
		yyVal = new FrameCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 36:
#line 285 "Parser.jay"
  {
		yyVal = new DisassembleCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 37:
#line 289 "Parser.jay"
  {
		yyVal = new DisassembleMethodCommand ((FrameExpression) yyVals[0+yyTop]);
	  }
  break;
case 38:
#line 293 "Parser.jay"
  {
		yyVal = new SelectProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 39:
#line 297 "Parser.jay"
  {
		yyVal = new BackgroundProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 40:
#line 301 "Parser.jay"
  {
		yyVal = new StopProcessCommand ((ProcessExpression) yyVals[0+yyTop]);
	  }
  break;
case 41:
#line 305 "Parser.jay"
  {
		yyVal = new ModuleOperationCommand ((ModuleListExpression) yyVals[-1+yyTop], (ModuleOperationListExpression) yyVals[0+yyTop]);
	  }
  break;
case 42:
#line 309 "Parser.jay"
  {
		yyVal = new ThreadGroupCreateCommand ((string) yyVals[0+yyTop]);
	  }
  break;
case 43:
#line 313 "Parser.jay"
  {
		yyVal = new ThreadGroupAddCommand ((string) yyVals[-1+yyTop], (ProcessListExpression) yyVals[0+yyTop]);
	  }
  break;
case 44:
#line 317 "Parser.jay"
  {
		yyVal = new ThreadGroupRemoveCommand ((string) yyVals[-1+yyTop], (ProcessListExpression) yyVals[0+yyTop]);
	  }
  break;
case 45:
#line 321 "Parser.jay"
  {
		yyVal = new ListCommand ((SourceExpression) yyVals[0+yyTop]);
	  }
  break;
case 46:
#line 325 "Parser.jay"
  {
		yyVal = new ListCommand (null);
	  }
  break;
case 47:
#line 332 "Parser.jay"
  {
		yyVal = new SaveCommand ((string) yyVals[0+yyTop]);
	  }
  break;
case 48:
#line 336 "Parser.jay"
  {
		yyVal = new ScriptingVariableAssignCommand ((string) yyVals[-2+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 49:
#line 340 "Parser.jay"
  {
		yyVal = new VariableAssignCommand ((VariableExpression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
	  }
  break;
case 50:
#line 344 "Parser.jay"
  {
		yyVal = new PrintCommand ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 51:
#line 348 "Parser.jay"
  {
		yyVal = new PrintCommand ((Expression) yyVals[0+yyTop]);
	  }
  break;
case 52:
#line 352 "Parser.jay"
  {
		yyVal = new ExamineCommand ((ExamineCommand.Format) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 53:
#line 356 "Parser.jay"
  {
		yyVal = new ExamineCommand ((ExamineCommand.Format) yyVals[-2+yyTop], (FrameExpression) yyVals[-1+yyTop], (long) yyVals[0+yyTop]);
	  }
  break;
case 54:
#line 360 "Parser.jay"
  {
		yyVal = new CallMethodCommand ((VariableExpression) yyVals[-3+yyTop], (Expression []) yyVals[-1+yyTop]);
	  }
  break;
case 55:
#line 364 "Parser.jay"
  {
		yyVal = new StartCommand ((ProgramArgumentsExpression) yyVals[0+yyTop]);
	  }
  break;
case 56:
#line 368 "Parser.jay"
  {
		yyVal = new RepeatCommand ((Command) yyVals[0+yyTop]);
	  }
  break;
case 57:
#line 375 "Parser.jay"
  {
		yyVal = TargetObjectKind.Unknown;
	  }
  break;
case 58:
#line 379 "Parser.jay"
  {
		yyVal = TargetObjectKind.Fundamental;
	  }
  break;
case 59:
#line 383 "Parser.jay"
  {
		yyVal = TargetObjectKind.Array;
	  }
  break;
case 60:
#line 387 "Parser.jay"
  {
		yyVal = TargetObjectKind.Struct;
	  }
  break;
case 61:
#line 391 "Parser.jay"
  {
		yyVal = TargetObjectKind.Class;
	  }
  break;
case 62:
#line 395 "Parser.jay"
  {
		yyVal = TargetObjectKind.Pointer;
	  }
  break;
case 63:
#line 402 "Parser.jay"
  {
		yyVal = new AssertKindCommand ((TargetObjectKind) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 64:
#line 406 "Parser.jay"
  {
		yyVal = new AssertAccessibleCommand ((VariableExpression) yyVals[0+yyTop], true);
	  }
  break;
case 65:
#line 410 "Parser.jay"
  {
		yyVal = new AssertAccessibleCommand ((VariableExpression) yyVals[0+yyTop], false);
	  }
  break;
case 66:
#line 414 "Parser.jay"
  {
		yyVal = new AssertTypeCommand ((string) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 67:
#line 418 "Parser.jay"
  {
		yyVal = new AssertContentsCommand ((string) yyVals[-1+yyTop], (VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 68:
#line 422 "Parser.jay"
  {
		yyVal = new AssertLineCommand ((int) yyVals[0+yyTop]);
	  }
  break;
case 69:
#line 429 "Parser.jay"
  {
		yyVal = new ArrayLengthExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 70:
#line 433 "Parser.jay"
  {
		yyVal = new ArrayLowerBoundExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 71:
#line 437 "Parser.jay"
  {
		yyVal = new ArrayUpperBoundExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 72:
#line 441 "Parser.jay"
  {
		yyVal = new NumberExpression ((long) yyVals[0+yyTop]);
	  }
  break;
case 73:
#line 445 "Parser.jay"
  {
		yyVal = new NumberExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 74:
#line 449 "Parser.jay"
  {
		yyVal = new StringExpression ((string) yyVals[0+yyTop]);
	  }
  break;
case 75:
#line 453 "Parser.jay"
  {
		yyVal = new BinaryOperator ((BinaryOperator.Kind) yyVals[-1+yyTop], (Expression) yyVals[-2+yyTop], (Expression) yyVals[0+yyTop]);
	  }
  break;
case 76:
#line 457 "Parser.jay"
  {
		yyVal = new ExpressionGroup ((Expression) yyVals[-1+yyTop]);
	  }
  break;
case 77:
#line 461 "Parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 78:
#line 468 "Parser.jay"
  {
		yyVal = new TypeOfExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 79:
#line 472 "Parser.jay"
  {
		yyVal = new TypeNameExpression ((FrameExpression) yyVals[-2+yyTop], (string) yyVals[-1+yyTop]);
	  }
  break;
case 81:
#line 480 "Parser.jay"
  {
		yyVal = String.Concat ((string) yyVals[-2+yyTop], ".", (string) yyVals[0+yyTop]);
	  }
  break;
case 82:
#line 487 "Parser.jay"
  {
		yyVal = new VariableDereferenceExpression ((VariableExpression) yyVals[0+yyTop]);
	  }
  break;
case 83:
#line 491 "Parser.jay"
  {
		yyVal = new ScriptingVariableReference ((string) yyVals[0+yyTop]);
	  }
  break;
case 84:
#line 495 "Parser.jay"
  {
		yyVal = new LastObjectExpression ();
	  }
  break;
case 85:
#line 499 "Parser.jay"
  {
		yyVal = new VariableReferenceExpression ((FrameExpression) yyVals[-2+yyTop], (string) yyVals[0+yyTop]);
	  }
  break;
case 86:
#line 503 "Parser.jay"
  {
		yyVal = new PointerExpression ((FrameExpression) yyVals[-2+yyTop], (long) yyVals[0+yyTop]);
	  }
  break;
case 87:
#line 507 "Parser.jay"
  {
		yyVal = new RegisterExpression ((FrameExpression) yyVals[-3+yyTop], (string) yyVals[-1+yyTop], (long) yyVals[0+yyTop]);
	  }
  break;
case 88:
#line 511 "Parser.jay"
  {
		yyVal = new StructAccessExpression ((FrameExpression) yyVals[-3+yyTop], (TypeExpression) yyVals[-2+yyTop], (string) yyVals[0+yyTop]);
	  }
  break;
case 89:
#line 515 "Parser.jay"
  {
		TypeExpression type = new TypeNameExpression ((FrameExpression) yyVals[-3+yyTop], (string) yyVals[-2+yyTop]);
		yyVal = new StructAccessExpression ((FrameExpression) yyVals[-3+yyTop], type, (string) yyVals[0+yyTop]);
	  }
  break;
case 90:
#line 520 "Parser.jay"
  {
		yyVal = new StructAccessExpression ((VariableExpression) yyVals[-2+yyTop], (string) yyVals[0+yyTop]);
	  }
  break;
case 91:
#line 524 "Parser.jay"
  {
		yyVal = new StructAccessExpression (new VariableDereferenceExpression ((VariableExpression) yyVals[-3+yyTop]), (string) yyVals[0+yyTop]);
	  }
  break;
case 92:
#line 528 "Parser.jay"
  {
		yyVal = new ArrayAccessExpression ((VariableExpression) yyVals[-3+yyTop], (Expression) yyVals[-1+yyTop]);
	  }
  break;
case 93:
#line 532 "Parser.jay"
  {
		yyVal = new InvocationExpression ((VariableExpression) yyVals[-3+yyTop], (Expression []) yyVals[-1+yyTop]);
	  }
  break;
case 94:
#line 536 "Parser.jay"
  {
		yyVal = new NewExpression ((FrameExpression) yyVals[-4+yyTop], (string) yyVals[-3+yyTop], (Expression []) yyVals[-1+yyTop]);
	  }
  break;
case 95:
#line 540 "Parser.jay"
  {
		yyVal = new ParentClassExpression ((VariableExpression) yyVals[-1+yyTop]);
	  }
  break;
case 96:
#line 544 "Parser.jay"
  {
		yyVal = (VariableExpression) yyVals[-1+yyTop];
	  }
  break;
case 97:
#line 551 "Parser.jay"
  {
		string[] args = new string [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (args, 0);
		yyVal = new ProgramArgumentsExpression (args);
	  }
  break;
case 98:
#line 560 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 99:
#line 567 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-1+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 100:
#line 577 "Parser.jay"
  {
		yyVal = new Expression [0];
	  }
  break;
case 101:
#line 581 "Parser.jay"
  {
		Expression[] args = new Expression [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (args, 0);

		yyVal = args;
	  }
  break;
case 102:
#line 591 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 103:
#line 598 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-2+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 104:
#line 608 "Parser.jay"
  {
		yyVal = ExamineCommand.Format.Standard;
	  }
  break;
case 105:
#line 612 "Parser.jay"
  {
		yyVal = new ExamineCommand.Format ((int)(long) yyVals[0+yyTop]);
	  }
  break;
case 106:
#line 619 "Parser.jay"
  {
		yyVal = -1;
	  }
  break;
case 107:
#line 623 "Parser.jay"
  {
		yyVal = (int) yyVals[0+yyTop];
	  }
  break;
case 108:
#line 630 "Parser.jay"
  {
		yyVal = (long) 0;
	  }
  break;
case 109:
#line 634 "Parser.jay"
  {
		yyVal = (long) yyVals[0+yyTop];
	  }
  break;
case 110:
#line 638 "Parser.jay"
  {
		yyVal = -(long) yyVals[0+yyTop];
	  }
  break;
case 111:
#line 645 "Parser.jay"
  {
		yyVal = (long)(int) yyVals[0+yyTop];
	  }
  break;
case 112:
#line 649 "Parser.jay"
  {
		yyVal = (long) yyVals[0+yyTop];
	  }
  break;
case 113:
#line 656 "Parser.jay"
  {
		yyVal = new BreakpointNumberExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 114:
#line 663 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ("main");
	  }
  break;
case 115:
#line 667 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ((string) yyVals[0+yyTop]);
	  }
  break;
case 116:
#line 671 "Parser.jay"
  {
		yyVal = new ThreadGroupExpression ("global");
	  }
  break;
case 117:
#line 678 "Parser.jay"
  {
		yyVal = new ProcessExpression (-1);
	  }
  break;
case 118:
#line 682 "Parser.jay"
  {
		yyVal = new ProcessExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 119:
#line 689 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[0+yyTop], -1);
	  }
  break;
case 120:
#line 693 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[-2+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 121:
#line 700 "Parser.jay"
  {
		yyVal = new ProcessExpression (-1);
	  }
  break;
case 122:
#line 704 "Parser.jay"
  {
		yyVal = new ProcessExpression ((int) yyVals[-1+yyTop]);
	  }
  break;
case 123:
#line 711 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[0+yyTop], -1);
	  }
  break;
case 124:
#line 715 "Parser.jay"
  {
		yyVal = new FrameExpression ((ProcessExpression) yyVals[-3+yyTop], (int) yyVals[-1+yyTop]);
	  }
  break;
case 125:
#line 722 "Parser.jay"
  {
		yyVal = -1;
	  }
  break;
case 126:
#line 726 "Parser.jay"
  {
		yyVal = yyVals[0+yyTop];
	  }
  break;
case 127:
#line 733 "Parser.jay"
  {
		yyVal = new SourceExpression ((VariableExpression) yyVals[-1+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 128:
#line 737 "Parser.jay"
  {
		yyVal = new SourceExpression ((int) yyVals[0+yyTop]);
	  }
  break;
case 129:
#line 741 "Parser.jay"
  {
		yyVal = new SourceExpression ((string) yyVals[0+yyTop]);
	  }
  break;
case 130:
#line 745 "Parser.jay"
  {
		yyVal = new SourceExpression ((string) yyVals[-2+yyTop], (int) yyVals[0+yyTop]);
	  }
  break;
case 131:
#line 752 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new ModuleListExpression (indices);
	  }
  break;
case 132:
#line 762 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new SourceListExpression (indices);
	  }
  break;
case 133:
#line 772 "Parser.jay"
  {
		int[] indices = new int [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (indices, 0);

		yyVal = new ProcessListExpression (indices);
	  }
  break;
case 134:
#line 782 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 135:
#line 789 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-2+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 136:
#line 799 "Parser.jay"
  {
		yyVal = ModuleOperation.Ignore;
	  }
  break;
case 137:
#line 803 "Parser.jay"
  {
		yyVal = ModuleOperation.UnIgnore;
	  }
  break;
case 138:
#line 807 "Parser.jay"
  {
		yyVal = ModuleOperation.UnIgnore;
	  }
  break;
case 139:
#line 811 "Parser.jay"
  {
		yyVal = ModuleOperation.Step;
	  }
  break;
case 140:
#line 815 "Parser.jay"
  {
		yyVal = ModuleOperation.DontStep;
	  }
  break;
case 141:
#line 822 "Parser.jay"
  {
		ModuleOperation[] operations = new ModuleOperation [((ArrayList) yyVals[0+yyTop]).Count];
		((ArrayList) yyVals[0+yyTop]).CopyTo (operations, 0);

		yyVal = new ModuleOperationListExpression (operations);
	  }
  break;
case 142:
#line 832 "Parser.jay"
  {
		ArrayList args = new ArrayList ();
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 143:
#line 839 "Parser.jay"
  {
		ArrayList args = (ArrayList) yyVals[-1+yyTop];
		args.Add (yyVals[0+yyTop]);

		yyVal = args;
	  }
  break;
case 144:
#line 849 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Mult;
	  }
  break;
case 145:
#line 853 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Plus;
	  }
  break;
case 146:
#line 857 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Minus;
	  }
  break;
case 147:
#line 861 "Parser.jay"
  {
		yyVal = BinaryOperator.Kind.Div;
	  }
  break;
#line default
        }
        yyTop -= yyLen[yyN];
        yyState = yyStates[yyTop];
        int yyM = yyLhs[yyN];
        if (yyState == 0 && yyM == 0) {
          if (debug != null) debug.shift(0, yyFinal);
          yyState = yyFinal;
          if (yyToken < 0) {
            yyToken = yyLex.advance() ? yyLex.token() : 0;
            if (debug != null)
               debug.lex(yyState, yyToken,yyname(yyToken), yyLex.value());
          }
          if (yyToken == 0) {
            if (debug != null) debug.accept(yyVal);
            return yyVal;
          }
          goto yyLoop;
        }
        if (((yyN = yyGindex[yyM]) != 0) && ((yyN += yyState) >= 0)
            && (yyN < yyTable.Length) && (yyCheck[yyN] == yyState))
          yyState = yyTable[yyN];
        else
          yyState = yyDgoto[yyM];
        if (debug != null) debug.shift(yyStates[yyTop], yyState);
	 goto yyLoop;
      }
    }
  }

   static  short [] yyLhs  = {              -1,
    0,    0,    0,    0,    0,    1,    1,    1,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    2,    2,    2,    2,    2,    2,    3,    3,    3,    3,
    3,    3,    3,    3,    3,    3,   22,   22,   22,   22,
   22,   22,    4,    4,    4,    4,    4,    4,   16,   16,
   16,   16,   16,   16,   16,   16,   16,   17,   17,   24,
   24,   10,   10,   10,   10,   10,   10,   10,   10,   10,
   10,   10,   10,   10,   10,   10,   21,   26,   26,   20,
   20,   27,   27,   18,   18,    6,    6,   25,   25,   25,
   28,   28,   13,   11,   11,   11,    5,    5,    7,    7,
   29,   29,   19,   19,   30,   30,   12,   12,   12,   12,
    8,    9,   15,   31,   31,   32,   32,   32,   32,   32,
   14,   33,   33,   23,   23,   23,   23,
  };
   static  short [] yyLen = {           2,
    0,    3,    2,    2,    2,    1,    1,    1,    2,    2,
    2,    2,    3,    2,    2,    3,    2,    2,    1,    1,
    2,    3,    3,    3,    2,    3,    3,    2,    2,    3,
    3,    4,    4,    4,    2,    2,    3,    2,    2,    2,
    3,    3,    4,    4,    2,    2,    2,    5,    4,    2,
    2,    3,    4,    5,    2,    2,    1,    1,    1,    1,
    1,    1,    4,    3,    4,    4,    4,    3,    4,    4,
    4,    1,    1,    1,    3,    3,    1,    4,    5,    1,
    3,    2,    2,    2,    3,    3,    4,    4,    4,    3,
    4,    4,    4,    6,    4,    3,    1,    1,    2,    0,
    1,    1,    3,    0,    2,    0,    1,    0,    2,    2,
    1,    1,    1,    0,    3,    3,    0,    2,    1,    3,
    0,    3,    1,    4,    0,    2,    2,    2,    1,    3,
    1,    1,    1,    1,    3,    1,    1,    2,    1,    2,
    1,    1,    2,    1,    1,    1,    1,
  };
   static  short [] yyDefRed = {            0,
    0,    0,    5,    3,    4,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   19,    0,    0,   20,    0,
    0,    0,    0,    0,    0,    0,    0,    6,    7,    8,
    0,    0,   35,   98,   55,    0,   21,    0,    0,    0,
    0,   25,    0,    0,   28,   29,   38,    9,    0,   17,
   18,   10,   11,   12,   14,   15,    0,    0,   73,   72,
   74,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   51,    0,    0,    0,   36,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   47,    0,    0,    0,    0,    0,   46,    0,   45,    0,
    0,    0,   56,    0,   39,   40,  134,    0,    0,    2,
  118,    0,   99,   22,   23,   24,    0,   26,   27,    0,
  107,   16,    0,    0,   31,    0,   83,   84,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  144,  145,  146,  147,    0,   80,    0,    0,    0,
    0,    0,   37,    0,    0,    0,    0,   57,   58,   59,
   60,   61,   62,    0,    0,    0,   68,    0,    0,    0,
    0,   42,    0,    0,    0,  128,    0,  127,  111,  112,
  105,    0,    0,    0,   13,    0,  139,  136,  137,   41,
  142,    0,    0,  120,  115,  116,  122,   96,   76,    0,
    0,    0,    0,    0,    0,    0,   90,    0,    0,    0,
    0,    0,    0,    0,   86,   85,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  113,   32,   33,   34,
   43,    0,   44,  130,  126,   53,    0,  140,  138,  143,
  135,   95,   69,   70,   71,    0,   78,    0,   91,   93,
    0,   92,    0,    0,   87,   88,   81,   89,  124,    0,
    0,    0,   79,    0,  109,  110,   94,
  };
  protected static  short [] yyDgoto  = {             2,
   37,   38,   39,   40,   42,  132,   43,  118,  129,   82,
   68,  109,  238,  200,  241,  219,  160,  111,   85,  220,
   45,  174,  156,  161,  265,   46,  221,  191,   86,  188,
  119,  201,  202,
  };
  protected static  short [] yySindex = {         -255,
 -250,  -50,    0,    0,    0, -187, -123,  146, -187, -187,
 -187, -187, -187, -187, -187, -187, -187, -187, -190, -124,
 -241,  -39,  -42,   15, -121,    0,  169,  -55,    0, -129,
   76,   56, -169, -187, -187, -108, -101,    0,    0,    0,
  -92,  -71,    0,    0,    0,  -89,    0, -187, -187, -187,
   76,    0, -108, -108,    0,    0,    0,    0,  -80,    0,
    0,    0,    0,    0,    0,    0, -227,  -41,    0,    0,
    0,  -63, -154,   76,  -90,  -67,  -61,  -56,  -53,  -40,
  -49,  216,  184,    0, -168,  -32, -187,    0, -134,   76,
  166,  -27,  209,   76,  -25,  -21,  -45, -187, -187, -187,
    0,  -22,  -19,  -17,  -26, -181,    0,   79,    0, -152,
   76,  223,    0, -187,    0,    0,    0, -157,   20,    0,
    0,   33,    0,    0,    0,    0,  216,    0,    0,   20,
    0,    0,   14,   16,    0,   17,    0,    0,  216,  171,
  241,   76,   76,   76,   76,   40,   76,   42,   24,  -90,
  -90,    0,    0,    0,    0,  -90,    0, -218,   47,   41,
 -246,   72,    0,  -28,  171,  -90,   76,    0,    0,    0,
    0,    0,    0,   76,  216,   76,    0,   76,   85,   85,
   85,    0, -108, -108,   88,    0,   90,    0,    0,    0,
    0,  216, -217,  -90,    0, -293,    0,    0,    0,    0,
    0, -157,   93,    0,    0,    0,    0,    0,    0,  187,
  192,  199,  204, -209,  211, -168,    0,   99,  184,  116,
  126,  -83,  184, -114,    0,    0,  152,  159,  161,  123,
   76,  184,  216,  216,  216,  216,    0,    0,    0,    0,
    0,   20,    0,    0,    0,    0,  129,    0,    0,    0,
    0,    0,    0,    0,    0,  -90,    0, -163,    0,    0,
  -90,    0, -152, -152,    0,    0,    0,    0,    0,  216,
    0,  148,    0,  184,    0,    0,    0,
  };
  protected static  short [] yyRindex = {            1,
    0,    0,    0,    0,    0, -143,    0,    0,  167,  167,
 -215,  167,  167,  167,  167,  167,  167,  167, -237,  -48,
 -143, -183,    0,    0,    0,    0,    0, -183,    0, -204,
 -183,    0,    0,  167,  167,    0,    0,    0,    0,    0,
    0,  170,    0,    0,    0,  172,    0, -143, -143, -143,
 -183,    0,    0,    0,    0,    0,    0,    0,  179,    0,
    0,    0,    0,    0,    0,    0,    0, -183,    0,    0,
    0,    0,    0, -183, -183,    0,    0,    0,    0, -132,
    0,   31,  180,    0,    0, -173, -143,    0,    0, -183,
    0,    0,    0, -183,    0,    0,    0, -108, -108, -108,
    0,    0,    0,    0,  182,    0,    0,  185,    0,    0,
 -257,    0,    0,  167,    0,    0,    0,    0, -161,    0,
    0,    0,    0,    0,    0,    0,  190,    0,    0,  206,
    0,    0,    0,    0,    0,    0,    0,    0,  145,  -78,
    0, -183, -183, -183, -183,    0, -183,    0,    0, -191,
 -183,    0,    0,    0,    0, -183,    0,    0,    0,    0,
    0,    0,    0,  228,    0, -183, -183,    0,    0,    0,
    0,    0,    0, -183,  215, -183,    0, -183,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  218,    0, -191,    0,    0,    0,    0,    0,    0,
    0,  227,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, -213,    0,
  221,    0, -159,  132,    0,    0,    0,    0,    0,    0,
 -183,  230,  237,  239,  244,  247,    0,    0,    0,    0,
    0,  249,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, -191,    0,    0,    0,    0,
 -183,    0,    0,    0,    0,    0,    0,    0,    0,  261,
   82,    0,    0, -127,    0,    0,    0,
  };
  protected static  short [] yyGindex = {            0,
  413,    0,    0,    0,    5,    0,  157,  471,    0,  -18,
    0,  457,  -15,    0,  342,  -20,  507,    0,  -38, -188,
    0,    0,    0, -110,    0,    0,    0,  -84,    0,    0,
  -51,  326,    0,
  };
  protected static  short [] yyTable = {            83,
    1,    1,  130,   91,  121,  247,  121,    3,  121,  108,
  121,  121,  112,   57,   58,   59,   60,   61,   62,   63,
   64,   65,   66,  228,  114,   41,  248,  114,  114,  114,
  114,  114,  127,  114,  133,  214,  114,  229,  115,  116,
  114,  146,  117,  224,  157,  225,  246,  117,   87,  108,
  158,  159,  249,  114,  141,  139,  140,  104,  102,  104,
  228,  104,  104,  104,  104,  102,  104,  272,  256,  104,
  121,  165,  193,  104,  121,  175,  121,  121,  121,   41,
  137,  186,  121,  134,  121,  121,  104,  100,  123,  138,
  123,   67,  192,  157,  123,  123,  131,  121,   75,  158,
  159,  114,  179,  180,  181,  258,  228,  137,  216,  131,
  189,  190,   75,  196,  117,  273,  138,  114,  195,   75,
  229,   75,  117,  210,  211,  212,  213,  164,  215,  121,
  222,  242,  242,  121,  104,  223,  138,   81,   69,   70,
   71,   44,   72,  101,  103,  232,   73,  110,  233,   74,
  104,  103,  114,   75,  117,  234,  120,  235,  131,  236,
  263,  264,  197,  121,  239,  240,   76,   77,   78,   79,
  121,  121,   69,   70,   71,  123,   72,   88,  275,  276,
   73,  123,  131,   74,  131,  131,   81,   75,  198,  199,
  152,  153,  154,  155,  122,   77,   77,  262,   77,  136,
   76,   77,   78,   79,  124,  125,  126,    4,    5,  105,
  142,   72,  270,  121,   80,  106,  143,  121,   74,  121,
  121,  144,   90,  105,  145,   72,   72,   72,  147,  106,
   81,   89,   74,  162,   74,   76,   90,  167,   90,  176,
  274,  177,  182,  163,  231,  183,   92,  184,   80,   76,
  178,   76,   93,   94,   95,   96,   97,  185,    1,    1,
  107,    6,    7,    8,    9,   10,   11,   12,   13,   14,
   15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
   25,   26,   27,   80,   28,   29,   30,   31,   77,   32,
   33,  203,   34,   35,   36,  204,  205,   80,  206,   80,
  207,  157,   77,  217,   77,   77,  218,   77,  226,   77,
  227,   77,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,  230,    1,    1,    1,    1,   54,
    1,    1,   72,    1,    1,    1,   73,  237,  148,   74,
  244,   93,  245,   90,  149,  251,  150,   93,  151,   93,
  259,   93,  187,   98,   99,  100,   76,    6,    7,    8,
    9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
   19,   20,   21,   22,   23,   24,   25,   26,   27,  108,
   28,   29,   30,   31,  260,   32,   33,  261,   34,   35,
   36,  108,   82,  108,  108,  108,  269,  271,  108,  108,
  108,  108,  108,  266,   80,  108,   82,   82,   82,   82,
  267,   82,  268,   82,  117,   82,  277,  119,   82,   97,
   47,   48,   49,   50,   51,  148,  106,   50,  166,  129,
  148,  149,  125,  150,  113,  151,  149,   30,  150,  208,
  151,   52,   53,   54,   55,   56,  148,  152,  153,  154,
  155,  148,  149,  132,  150,  252,  151,  149,  148,  150,
  253,  151,   64,  148,  149,   52,  150,  254,  151,  149,
  148,  150,  255,  151,  141,  148,  149,   49,  150,  257,
  151,  149,  148,  150,   66,  151,   63,   83,  149,  101,
  194,   67,  151,   83,   65,   83,  133,   83,  168,  169,
  170,  171,  172,  173,  152,  153,  154,  155,   48,  209,
  102,  103,  104,  128,  135,  243,   84,  250,
  };
  protected static  short [] yyCheck = {            20,
    0,  257,   54,   22,  262,  194,  264,  258,  266,   28,
  268,  269,   31,    9,   10,   11,   12,   13,   14,   15,
   16,   17,   18,  270,  262,  267,  320,  265,  266,  267,
  268,  269,   51,  271,  262,  146,  274,  284,   34,   35,
  278,   80,  258,  262,  262,  264,  264,  263,  290,   68,
  268,  269,  346,  291,   75,   74,   75,  262,  272,  264,
  270,  266,  267,  268,  269,  279,  271,  256,  278,  274,
  262,   90,  111,  278,  266,   94,  268,  269,  262,  267,
  262,  263,  266,  311,  268,  269,  291,  279,  262,  271,
  264,  282,  111,  262,  268,  269,  258,  355,  258,  268,
  269,  339,   98,   99,  100,  216,  270,  262,  147,  271,
  263,  264,  272,  271,  258,  279,  271,  355,  114,  279,
  284,  281,  266,  142,  143,  144,  145,  262,  147,  262,
  151,  183,  184,  266,  339,  156,  271,  355,  263,  264,
  265,  265,  267,  265,  272,  166,  271,  277,  167,  274,
  355,  279,  322,  278,  263,  174,  258,  176,  320,  178,
  275,  276,  320,  355,  180,  181,  291,  292,  293,  294,
  263,  355,  263,  264,  265,  265,  267,   21,  263,  264,
  271,  355,  263,  274,  346,  347,  355,  278,  346,  347,
  274,  275,  276,  277,  266,  274,  275,  281,  277,  263,
  291,  292,  293,  294,   48,   49,   50,  258,  259,  265,
  278,  267,  231,  262,  339,  271,  278,  266,  274,  268,
  269,  278,  278,  265,  278,  267,  267,  267,  278,  271,
  355,  271,  274,  266,  274,  291,  278,  265,  278,  265,
  261,  263,  265,   87,  273,  265,  289,  265,  339,  291,
  296,  291,  295,  296,  297,  298,  299,  284,  258,  259,
  316,  312,  313,  314,  315,  316,  317,  318,  319,  320,
  321,  322,  323,  324,  325,  326,  327,  328,  329,  330,
  331,  332,  333,  339,  335,  336,  337,  338,  258,  340,
  341,  272,  343,  344,  345,  263,  283,  339,  283,  339,
  284,  262,  272,  262,  274,  275,  283,  277,  262,  279,
  270,  281,  312,  313,  314,  315,  316,  317,  318,  319,
  320,  321,  322,  323,  324,  325,  326,  327,  328,  329,
  330,  331,  332,  333,  263,  335,  336,  337,  338,  258,
  340,  341,  267,  343,  344,  345,  271,  263,  270,  274,
  263,  270,  263,  278,  276,  263,  278,  276,  280,  278,
  262,  280,  284,  349,  350,  351,  291,  312,  313,  314,
  315,  316,  317,  318,  319,  320,  321,  322,  323,  324,
  325,  326,  327,  328,  329,  330,  331,  332,  333,  258,
  335,  336,  337,  338,  279,  340,  341,  272,  343,  344,
  345,  270,  258,  272,  273,  274,  284,  279,  277,  278,
  279,  280,  281,  262,  339,  284,  272,  273,  274,  275,
  262,  277,  262,  279,  258,  281,  279,  258,  284,  258,
  285,  286,  287,  288,  289,  270,  258,  258,  273,  258,
  270,  276,  258,  278,   32,  280,  276,  258,  278,  279,
  280,  306,  307,  308,  309,  310,  270,  274,  275,  276,
  277,  270,  276,  258,  278,  279,  280,  276,  270,  278,
  279,  280,  258,  270,  276,  258,  278,  279,  280,  276,
  270,  278,  279,  280,  258,  270,  276,  258,  278,  279,
  280,  276,  270,  278,  258,  280,  258,  270,  276,  279,
  278,  258,  280,  276,  258,  278,  258,  280,  300,  301,
  302,  303,  304,  305,  274,  275,  276,  277,  258,  279,
  352,  353,  354,   53,   68,  184,   20,  202,
  };

#line 866 "Parser.jay"

public Parser (ScriptingContext context, string name)
{
	this.reader = new MyTextReader ();
	this.current_context = context;

	lexer = new Tokenizer (context, reader, name);
}

public bool Parse (string text)
{
	try {
		reader.Text = text;
		lexer.restart ();
		if (yacc_verbose_flag)
			yyparse (lexer, new yydebug.yyDebugSimple ());
		else
			yyparse (lexer);
		return true;
	} catch (Exception e){
		// Please do not remove this, it is used during debugging
		// of the grammar
		//
		current_context.Error (lexer.location + "  : Parsing error ");
		current_context.Error (e.ToString ());
		return false;
	}
}

/* end end end */
}
#line default
namespace yydebug {
        using System;
	 internal interface yyDebug {
		 void push (int state, Object value);
		 void lex (int state, int token, string name, Object value);
		 void shift (int from, int to, int errorFlag);
		 void pop (int state);
		 void discard (int state, int token, string name, Object value);
		 void reduce (int from, int to, int rule, string text, int len);
		 void shift (int from, int to);
		 void accept (Object value);
		 void error (string message);
		 void reject ();
	 }
	 
	 class yyDebugSimple : yyDebug {
		 void println (string s){
			 Console.WriteLine (s);
		 }
		 
		 public void push (int state, Object value) {
			 println ("push\tstate "+state+"\tvalue "+value);
		 }
		 
		 public void lex (int state, int token, string name, Object value) {
			 println("lex\tstate "+state+"\treading "+name+"\tvalue "+value);
		 }
		 
		 public void shift (int from, int to, int errorFlag) {
			 switch (errorFlag) {
			 default:				// normally
				 println("shift\tfrom state "+from+" to "+to);
				 break;
			 case 0: case 1: case 2:		// in error recovery
				 println("shift\tfrom state "+from+" to "+to
					     +"\t"+errorFlag+" left to recover");
				 break;
			 case 3:				// normally
				 println("shift\tfrom state "+from+" to "+to+"\ton error");
				 break;
			 }
		 }
		 
		 public void pop (int state) {
			 println("pop\tstate "+state+"\ton error");
		 }
		 
		 public void discard (int state, int token, string name, Object value) {
			 println("discard\tstate "+state+"\ttoken "+name+"\tvalue "+value);
		 }
		 
		 public void reduce (int from, int to, int rule, string text, int len) {
			 println("reduce\tstate "+from+"\tuncover "+to
				     +"\trule ("+rule+") "+text);
		 }
		 
		 public void shift (int from, int to) {
			 println("goto\tfrom state "+from+" to "+to);
		 }
		 
		 public void accept (Object value) {
			 println("accept\tvalue "+value);
		 }
		 
		 public void error (string message) {
			 println("error\t"+message);
		 }
		 
		 public void reject () {
			 println("reject");
		 }
		 
	 }
}
// %token constants
 class Token {
  public const int QUIT = 257;
  public const int EOL = 258;
  public const int EOF = 259;
  public const int NONE = 260;
  public const int ERROR = 261;
  public const int IDENTIFIER = 262;
  public const int INTEGER = 263;
  public const int NUMBER = 264;
  public const int STRING = 265;
  public const int HASH = 266;
  public const int AT = 267;
  public const int PERCENT = 268;
  public const int DOLLAR = 269;
  public const int DOT = 270;
  public const int BANG = 271;
  public const int COMMA = 272;
  public const int ASSIGN = 273;
  public const int STAR = 274;
  public const int PLUS = 275;
  public const int MINUS = 276;
  public const int DIV = 277;
  public const int OPEN_PARENS = 278;
  public const int CLOSE_PARENS = 279;
  public const int OPEN_BRACKET = 280;
  public const int CLOSE_BRACKET = 281;
  public const int OP_LT = 282;
  public const int OP_GT = 283;
  public const int COLON = 284;
  public const int PROCESSES = 285;
  public const int REGISTERS = 286;
  public const int PARAMETERS = 287;
  public const int LOCALS = 288;
  public const int TYPE = 289;
  public const int METHOD = 290;
  public const int PARENT = 291;
  public const int LENGTH = 292;
  public const int LOWER = 293;
  public const int UPPER = 294;
  public const int KIND = 295;
  public const int ACCESSIBLE = 296;
  public const int CONTENTS = 297;
  public const int LINE = 298;
  public const int NOT = 299;
  public const int UNKNOWN = 300;
  public const int FUNDAMENTAL = 301;
  public const int ARRAY = 302;
  public const int STRUCT = 303;
  public const int CLASS = 304;
  public const int POINTER = 305;
  public const int MODULES = 306;
  public const int SOURCES = 307;
  public const int METHODS = 308;
  public const int BREAKPOINTS = 309;
  public const int THREADGROUPS = 310;
  public const int GLOBAL = 311;
  public const int FRAME = 312;
  public const int START = 313;
  public const int SHOW = 314;
  public const int PROCESS = 315;
  public const int CONTINUE = 316;
  public const int BACKTRACE = 317;
  public const int UP = 318;
  public const int DOWN = 319;
  public const int STEP = 320;
  public const int NEXT = 321;
  public const int STEPI = 322;
  public const int NEXTI = 323;
  public const int FINISH = 324;
  public const int BREAK = 325;
  public const int PRINT = 326;
  public const int DISASSEMBLE = 327;
  public const int SET = 328;
  public const int ASSERT = 329;
  public const int BREAKPOINT = 330;
  public const int SAVE = 331;
  public const int KILL = 332;
  public const int THREADGROUP = 333;
  public const int SEARCH = 334;
  public const int LIST = 335;
  public const int RUN = 336;
  public const int EXAMINE = 337;
  public const int CALL = 338;
  public const int NEW = 339;
  public const int REPEAT = 340;
  public const int NATIVE = 341;
  public const int SELECT = 342;
  public const int BACKGROUND = 343;
  public const int STOP = 344;
  public const int MODULE = 345;
  public const int IGNORE = 346;
  public const int UNIGNORE = 347;
  public const int ALL = 348;
  public const int ENABLE = 349;
  public const int DISABLE = 350;
  public const int DELETE = 351;
  public const int CREATE = 352;
  public const int ADD = 353;
  public const int REMOVE = 354;
  public const int TYPEOF = 355;
  public const int HELP = 356;
  public const int yyErrorCode = 256;
 }
 namespace yyParser {
  using System;
  /** thrown for irrecoverable syntax errors and stack overflow.
    */
  internal class yyException : System.Exception {
    public yyException (string message) : base (message) {
    }
  }

  /** must be implemented by a scanner object to supply input to the parser.
    */
  internal interface yyInput {
    /** move on to next token.
        @return false if positioned beyond tokens.
        @throws IOException on input error.
      */
    bool advance (); // throws java.io.IOException;
    /** classifies current token.
        Should not be called if advance() returned false.
        @return current %token or single character.
      */
    int token ();
    /** associated with current token.
        Should not be called if advance() returned false.
        @return value for token().
      */
    Object value ();
  }
 }
} // close outermost namespace, that MUST HAVE BEEN opened in the prolog
